# 百度贴吧自动签到脚本

## 项目简介

这是一个用于百度贴吧自动签到的青龙面板脚本，支持多账号管理、自动获取关注的贴吧列表并执行签到操作，同时提供签到结果通知功能。脚本通过读取青龙环境变量或配置文件中的Cookie信息，实现无人值守的贴吧签到任务。

## 功能特点

- 自动获取所有关注的百度贴吧并执行签到
- 支持多账号同时管理和签到
- 智能处理已签到、被屏蔽的贴吧
- 详细的签到结果统计和日志输出
- 支持青龙面板通知功能，实时推送签到结果
- 自动处理网络请求异常，包含重试机制

## 前提条件

1. 已部署青龙面板环境（v2或v2.1+）
2. 拥有有效的百度账号Cookie（包含BDUSS字段）
3. 青龙面板已安装通知模块（可选，用于推送签到结果）

## 配置步骤

### 1. 获取百度贴吧Cookie

#### 获取BDUSS的方法：

1. 使用浏览器登录百度账号
2. 访问百度贴吧任意页面（如 https://tieba.baidu.com）
3. 按F12打开开发者工具，切换到"应用程序"(Application)选项卡
4. 在左侧菜单中选择"Cookie"，找到`BDUSS`字段
5. 复制`BDUSS`的值，格式类似：`xxx&yyy=zzz; ...`

#### 完整Cookie获取方法：

1. 登录百度贴吧后，右键网页空白处选择"检查"
2. 在开发者工具中切换到"网络"(Network)选项卡
3. 刷新页面，找到任意请求（如`tbs`或`like`）
4. 在请求详情中找到"请求标头"(Request Headers)
5. 复制整个`Cookie`字段的值

### 2. 配置青龙环境变量

在青龙面板中添加环境变量：

1. 进入青龙面板 -> 环境变量 -> 新增
2. 变量名：`TIEBA`
3. 变量值：粘贴获取的Cookie（多账号用换行分隔）

**多账号示例：**
```
BDUSS=xxx1; STOKEN=yyy1; ...
BDUSS=xxx2; STOKEN=yyy2; ...
```

### 3. 配置文件方式（可选）

如果不想使用环境变量，也可以在青龙中创建配置文件：

1. 在青龙脚本目录下创建`config.json`文件
2. 内容格式：
```json
{
  "TIEBA": [
    {"cookie": "BDUSS=xxx1; STOKEN=yyy1; ..."},
    {"cookie": "BDUSS=xxx2; STOKEN=yyy2; ..."}
  ]
}
```
3. 脚本会优先读取环境变量，若不存在则尝试读取配置文件

## 使用方法

1. 将脚本文件上传到青龙面板的`scripts`目录
2. 在青龙面板中手动运行脚本，或设置定时任务
3. 查看脚本运行日志或接收通知获取签到结果

## 定时任务设置

在青龙面板中设置定时任务：

1. 进入青龙面板 -> 定时任务 -> 新增
2. 任务名称：自定义（如"百度贴吧签到"）
3. 命令：`python3 /ql/scripts/tieba_sign.py`（根据实际路径调整）
4. Cron表达式：`0 0 1 * * ?`（每天凌晨1点执行，可自定义）

**常用Cron示例：**
- 每天0点执行：`0 0 * * * ?`
- 每周一0点执行：`0 0 * * 1 ?`
- 每月1-5号0点执行：`0 0 1-5 * * ?`

## 通知功能配置

脚本支持青龙面板的通知功能，需确保青龙已安装`notify.py`通知模块：

1. 确保青龙面板中存在`notify.py`文件
2. 脚本会自动调用`notify.send`方法发送通知
3. 签到完成后会汇总所有账号结果并发送通知

## 脚本日志说明

脚本运行时会输出详细日志：

- 成功签到：显示贴吧名称和签到排名
- 已签到：提示今日已完成签到
- 被屏蔽：显示贴吧已被屏蔽
- 错误信息：包含具体错误码和原因
- 账号间延迟：处理多账号时的等待时间
- 汇总统计：显示各账号签到结果和总体统计

## 常见问题

### 1. 签到失败，提示"登录失败，Cookie异常"

- 原因：Cookie已过期或缺少必要字段
- 解决方法：重新获取最新Cookie，确保包含`BDUSS`字段

### 2. 无法获取贴吧列表

- 原因：网络请求异常或账号权限问题
- 解决方法：检查网络连接，尝试更换Cookie

### 3. 提示"今日已签到"

- 原因：该贴吧当天已完成签到
- 解决方法：无需处理，脚本会自动跳过已签到的贴吧

### 4. 通知发送失败

- 原因：青龙未安装通知模块或模块路径错误
- 解决方法：安装`notify.py`通知模块，或检查模块路径

### 5. 多账号处理时速度过慢

- 原因：脚本为避免频繁请求设置了延迟
- 解决方法：如需加快速度，可调整`sign_forums`方法中的延迟参数

## 脚本更新

1. 如需更新脚本，直接替换青龙面板中的脚本文件
2. 建议定期更新以适应百度贴吧接口变化
3. 若签到失败率突然升高，可能是接口变动，需检查脚本是否需要更新

## 注意事项

1. 请勿频繁使用同一Cookie大量签到，避免账号异常
2. Cookie有效期通常为7-15天，建议定期更新
3. 脚本仅供个人使用，请勿用于商业用途
4. 百度可能随时变更接口，脚本可能需要不定期维护
5. 多账号处理时，账号间延迟可避免触发风控机制

通过以上步骤配置后，脚本将自动完成百度贴吧的签到任务，并通过通知推送结果，实现无人值守的贴吧签到管理。